PAYROLL_USECOLS: list = [
    "Company Short Name",
    "Pay Statement Type",
    "Employee Id",
    "Name",
    "Base Hourly Rate",
    "E Regular Hours",
    "E Overtime Hours",
    "E Vacation Hours",
    "E Charge Tips Amount",
    "E Opp Pay Week 1 Amount",
    "E Opp Pay Week 2 Amount",
    "D EE Uniform Amount",
    "Default Job",
    "Default Work Location"
]

TIMESHEET_USECOLS: list = [
    "name",
    "minorJob",
    "minutesWorked",
    "startDate",
    "endDate",
    "regularMinutes",
    "overtimeMinutes"
]

TIPSHEET_USECOLS: list = ["firstName", "lastName", "chargeTips", "cashTips"]
